@@ -208,6 +208,20 @@ get_beta <- function(beta, p, n, fastcpd_family, sigma_) {
   }
 }
 
+get_convexity_coef <- function(
+  convexity_coef_is_set,
+  convexity_coef,
+  cost_adjustment,
+  fastcpd_family,
+  n,
+  p
+) {
+  if (!convexity_coef_is_set && (fastcpd_family %in% c("mgaussian", "lasso"))) {
+    convexity_coef <- -Inf
+  }
+  convexity_coef
+}
+
 get_p_response <- function(family, y, data) {
   if (family %in% c(
     "mean", "variance", "meanvariance", "mv", "ma", "arma", "arima", "garch"
